@@ -765,7 +765,7 @@ void ConfigElem::slotUIDsReceived( TDEIO::Job * job )
 {
   int number;                 //an extracted mail number
   TQString uid;                //an extracted uid
-  bool corruptData = false;   //set to TRUE, if a data is corrupt
+  bool corruptData = false;   //set to true, if a data is corrupt
   bool isNew = false;         //state of the received mail
 
   //stop timeout timer
@@ -936,7 +936,7 @@ void ConfigElem::slotSizesReceived( TDEIO::Job * job )
 {
   int number;                 //an extracted mail number
   long size;                   //an extracted size
-  bool corruptData = false;   //set to TRUE, if a data is corrupt
+  bool corruptData = false;   //set to true, if a data is corrupt
 
   //stop timeout timer
   pop3Timer->stop();
@@ -1532,9 +1532,9 @@ void ConfigElem::slotMailDownloadedForAction(TDEIO::Job * job)
     TQString mail( mailbody );                 //convert mailtext
     FilterAction_Type action = firstMail.data().action; //get action
 
-    bool resultMove = false;    //TRUE - mail is written into the mailbox
-    bool resultSpam = false;  //TRUE - mail is Spam
-    bool deleteIt = false;    //TRUE - mail shall be deleted
+    bool resultMove = false;    //true - mail is written into the mailbox
+    bool resultSpam = false;  //true - mail is Spam
+    bool deleteIt = false;    //true - mail shall be deleted
     bool resultAction = false;  //True - the action was succesful performed
 
     switch( action )
