@@ -199,7 +199,7 @@ bool ConfigList::AutoRefreshOn( ) const
 
 bool ConfigList::hasActiveAccounts( )
 {
-  bool activeAccountFound = false;    //when a active account was found, this will be set to TRUE
+  bool activeAccountFound = false;    //when a active account was found, this will be set to true
   ConfigElem* currentAccount;         //saved current account
   ConfigElem* Account;                //used by the search
 
@@ -255,7 +255,7 @@ ConfigElem* ConfigList::getSelectedAccount( )
     return account;
 
   //iterate over all accounts
-  bool selectedAccountFound = false;  //is TRUE, if a selected account was found
+  bool selectedAccountFound = false;  //is true, if a selected account was found
   while( account != NULL && !selectedAccountFound )
   {
     //get next account
@@ -269,7 +269,7 @@ ConfigElem* ConfigList::getSelectedAccount( )
   }
 
   //return the current account if we have found a selected account
-  //otherwise return FALSE
+  //otherwise return false
   if( selectedAccountFound )
     return account;
   else
@@ -289,7 +289,7 @@ void ConfigList::deleteSelectedMails( )
   connectAccounts();
 
   //inserts an item for every account which will get an order to delete
-  //its selected mails. The key is the account name and the data is TRUE.
+  //its selected mails. The key is the account name and the data is true.
   //it is important to do this in a seperate iteration because this avoids
   //race conditions
   while( ( account = it.current() ) != NULL )
@@ -319,10 +319,10 @@ void ConfigList::slotAccountConfigChanged( )
 
 void ConfigList::slotCheckDeletionState( TQString account )
 {
-  bool accountDeleting = false;     //set to TRUE if an account is still deleting
+  bool accountDeleting = false;     //set to true if an account is still deleting
   AccountTaskMap_Type::Iterator it; //iterator over the account deletion map
 
-  //set the appropriate item in AccountDeletionMap to FALSE
+  //set the appropriate item in AccountDeletionMap to false
   AccountDeletionMap[ account ] = false;
 
   //iterate over the account deletion map to check, whether all accounts
@@ -391,7 +391,7 @@ TQStringList ConfigList::getSelectedSubjects( ) const
 
 bool ConfigList::hasSelectedMails( )
 {
-  bool foundSelected = false;                 //set to TRUE, when an account with selected mails was found
+  bool foundSelected = false;                 //set to true, when an account with selected mails was found
   TQPtrListIterator<ConfigElem> it( *this );   //to iterate over all accounts
   ConfigElem* account;                        //current account
 
@@ -420,7 +420,7 @@ void ConfigList::showSelectedMails( )
   connectAccounts();
 
   //inserts an item for every account which will get an order to show
-  //its selected mails. The key is the account name and the data is TRUE.
+  //its selected mails. The key is the account name and the data is true.
   //it is important to do this in a seperate iteration because this avoids
   //race conditions
   while( ( account = it.current() ) != NULL )
@@ -446,10 +446,10 @@ void ConfigList::showSelectedMails( )
 
 void ConfigList::slotCheckShowBodiesState( TQString account )
 {
-  bool accountDownloading = false;    //set to TRUE if an account is downloading mail body yet
+  bool accountDownloading = false;    //set to true if an account is downloading mail body yet
   AccountTaskMap_Type::Iterator it;   //iterator over the account map
 
-  //set the appropriate item in AccountShowBodiesMap to FALSE
+  //set the appropriate item in AccountShowBodiesMap to false
   AccountShowBodiesMap[ account ] = false;
 
   //iterate over the account map to check, whether all accounts
@@ -524,7 +524,7 @@ void ConfigList::refreshMailLists( FilterLog* log )
   connectAccounts();
 
   //inserts an item for every account which will get an order to refresh
-  //its mail list. The key is the account name and the data is TRUE.
+  //its mail list. The key is the account name and the data is true.
   //it is important to do this in a seperate iteration because this avoids
   //race conditions
   while( ( account = it.current() ) != NULL )
@@ -550,10 +550,10 @@ void ConfigList::refreshMailLists( FilterLog* log )
 
 void ConfigList::slotCheckRefreshState( TQString account )
 {
-  bool accountRefreshing = false;    //set to TRUE if an account is still refreshing
+  bool accountRefreshing = false;    //set to true if an account is still refreshing
   AccountTaskMap_Type::Iterator it;   //iterator over the account map
 
-  //set the appropriate item in AccountRefreshMap to FALSE
+  //set the appropriate item in AccountRefreshMap to false
   AccountRefreshMap[ account ] = false;
 
   //iterate over the account map to check whether all accounts
@@ -954,7 +954,7 @@ bool ConfigList::showConnectionErrors( ) const
 
 bool ConfigList::hasAccount( const TQString & name ) const
 {
-  bool found = false;                       //TRUE if we have found the given account
+  bool found = false;                       //true if we have found the given account
   ConfigElem* account;                      //account from which we want to get its name
   TQPtrListIterator<ConfigElem> it( *this ); //iterator for the account list
 
@@ -964,7 +964,7 @@ bool ConfigList::hasAccount( const TQString & name ) const
     //increment iterator to next account
     ++it;
 
-    //if current account is the searched one set found to TRUE
+    //if current account is the searched one set found to true
     if( account->getAccountName() == name )
       found = true;
   }
@@ -974,7 +974,7 @@ bool ConfigList::hasAccount( const TQString & name ) const
 
 ConfigElem * ConfigList::getAccount( const TQString & name ) const
 {
-  bool found = false;                       //TRUE if we have found the given account
+  bool found = false;                       //true if we have found the given account
   ConfigElem* account = NULL;               //account from which we want to get its name
   TQPtrListIterator<ConfigElem> it( *this ); //iterator for the account list
   ConfigElem* returnValue = NULL;
@@ -985,7 +985,7 @@ ConfigElem * ConfigList::getAccount( const TQString & name ) const
     //increment iterator to next account
     ++it;
 
-    //if current account is the searched one set found to TRUE
+    //if current account is the searched one set found to true
     if( account->getAccountName() == name )
     {
       found = true;
