@@ -35,7 +35,7 @@
  */
 class ConfigDisplay : public TDECModule
 {
-Q_OBJECT
+TQ_OBJECT
 
   public:
     /**
