@@ -11,7 +11,7 @@
 //
 
 //TQt headers
-#include <ntqstring.h>
+#include <tqstring.h>
 
 //KDE headers
 #include <kurl.h>
