@@ -77,14 +77,14 @@ FilterSetupDialog::FilterSetupDialog( TQWidget* parent, FilterSetupItem* item )
   layButtons->addWidget( btnAddCriteria );
   layButtons->addWidget( btnRemoveCriteria );
   layButtons->addStretch();
-  connect( btnAddCriteria, SIGNAL( clicked() ), this, SLOT( slotAddCriteriaWidget() ) );
-  connect( btnRemoveCriteria, SIGNAL( clicked() ), this, SLOT( slotRemoveCriteriaWidget() ) );
+  connect( btnAddCriteria, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotAddCriteriaWidget() ) );
+  connect( btnRemoveCriteria, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotRemoveCriteriaWidget() ) );
 
   //create combobox to select action
   cmbAction = new KComboBox( gboxAction, "cmbAction" );
   layAction->addWidget( cmbAction );
   TQToolTip::add( cmbAction, i18n( "Choose the action for all mails which are filtered by this filter." ) );
-  connect( cmbAction, SIGNAL( activated( int ) ), this, SLOT( slotActionChanged( int ) ) );
+  connect( cmbAction, TQ_SIGNAL( activated( int ) ), this, TQ_SLOT( slotActionChanged( int ) ) );
 
   //insert items
   cmbAction->insertItem( i18n( "Show" ), ID_COMBO_FILTER_ACTION_PASS );
@@ -102,7 +102,7 @@ FilterSetupDialog::FilterSetupDialog( TQWidget* parent, FilterSetupItem* item )
   btnMailboxWizard= new KPushButton( KGuiItem( TQString::null, "wizard" ), gboxAction );
   layAction->addWidget( btnMailboxWizard );
   TQToolTip::add( btnMailboxWizard, i18n( "Choose the mailbox" ) );
-  connect( btnMailboxWizard, SIGNAL( clicked() ), this, SLOT( slotOpenMailBoxWizard() ) );
+  connect( btnMailboxWizard, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotOpenMailBoxWizard() ) );
 
   //set default action
   switch( DEFAULT_FILTER_ACTION )
