@@ -13,7 +13,7 @@
 #define MAILBOXWIZARDLISTITEM_H
 
 //TQt-Headers
-#include <ntqlistview.h>
+#include <tqlistview.h>
 
 //KDE-Headers
 #include <tdelistview.h>
