@@ -60,16 +60,16 @@ KShowMailApp::KShowMailApp()
 
   //connect signals with slots
 
-  connect (m_pDockWindow, SIGNAL (quitSelected ()), SLOT (slotForceClose ()));
-  connect (m_pTimer, SIGNAL (timeout ()), SLOT (slotRefresh ()));
-  connect (m_pView->m_pListAccounts, SIGNAL (currentChanged(TQListViewItem*)), SLOT(slotAccountActivated(TQListViewItem*)));
-  connect (m_pView, SIGNAL (signalActiveChanged()), SLOT (slotRefreshView()));
+  connect (m_pDockWindow, TQ_SIGNAL (quitSelected ()), TQ_SLOT (slotForceClose ()));
+  connect (m_pTimer, TQ_SIGNAL (timeout ()), TQ_SLOT (slotRefresh ()));
+  connect (m_pView->m_pListAccounts, TQ_SIGNAL (currentChanged(TQListViewItem*)), TQ_SLOT(slotAccountActivated(TQListViewItem*)));
+  connect (m_pView, TQ_SIGNAL (signalActiveChanged()), TQ_SLOT (slotRefreshView()));
 
-  connect( &m_ConfigList, SIGNAL( sigDeleteReady() ), this, SLOT( slotDeletionReady() ) );
-  connect( &m_ConfigList, SIGNAL( sigShowBodiesReady() ), this, SLOT( slotShowMessageReady() ) );
-  connect( &m_ConfigList, SIGNAL( sigMessageWindowOpened() ), this, SLOT( slotNormalCursor() ) );
-  connect( &m_ConfigList, SIGNAL( sigAllMessageWindowsClosed() ), this, SLOT( slotWaitingCursor() ) );
-  connect( &m_ConfigList, SIGNAL( sigRefreshReady() ), this, SLOT( slotRefreshReady() ) );
+  connect( &m_ConfigList, TQ_SIGNAL( sigDeleteReady() ), this, TQ_SLOT( slotDeletionReady() ) );
+  connect( &m_ConfigList, TQ_SIGNAL( sigShowBodiesReady() ), this, TQ_SLOT( slotShowMessageReady() ) );
+  connect( &m_ConfigList, TQ_SIGNAL( sigMessageWindowOpened() ), this, TQ_SLOT( slotNormalCursor() ) );
+  connect( &m_ConfigList, TQ_SIGNAL( sigAllMessageWindowsClosed() ), this, TQ_SLOT( slotWaitingCursor() ) );
+  connect( &m_ConfigList, TQ_SIGNAL( sigRefreshReady() ), this, TQ_SLOT( slotRefreshReady() ) );
 
   //show welcome message
   KMessageBox::information( NULL, i18n( "Thank You for using KShowmail.\nPlease use the feedback dialog to tell us your experience with this program." ), i18n("Welcome"), "WelcomeMessage" );
@@ -126,31 +126,31 @@ void KShowMailApp::timerEvent (TQTimerEvent *)
 void KShowMailApp::initActions ()
 {
   // file menu
-  KStdAction::quit( this, SLOT( slotFileQuit() ), actionCollection() );
+  KStdAction::quit( this, TQ_SLOT( slotFileQuit() ), actionCollection() );
 
   // action menu
-  m_actionRefresh = new TDEAction( i18n( "&Refresh messages" ), "reload", Key_F5, this, SLOT( slotRefresh() ), actionCollection(), "refresh" );
-  new TDEAction( i18n( "Show &header of highlighted messages" ), "letter-closed", Key_F2, this, SLOT( slotShowHeader() ), actionCollection(), "show_header" );
-  new TDEAction( i18n( "Show &complete highlighted messages" ), "letter-open", Key_F3, this, SLOT( slotShowMessage() ), actionCollection(), "show_complete" );
-  new TDEAction( i18n( "&Delete highlighted messages" ), "eraser", Key_Delete, this, SLOT( slotDelete() ), actionCollection(), "delete" );
-  new TDEAction( i18n( "S&top current transfer" ), "process-stop", 0, this, SLOT( slotStop() ), actionCollection(), "stop" );
-  new TDEAction( i18n( "Show Filter Log" ), "text-x-log", Key_F4, this, SLOT( slotShowFilterLog() ), actionCollection(), "show_filterlog" );
-  new TDEAction( i18n( "Add sender to whitelist" ), "add_user", 0, this, SLOT( slotAddToWhitelist() ), actionCollection(), "addWhitelist" );
-  new TDEAction( i18n( "Add sender to blacklist" ), "delete_user", 0, this, SLOT( slotAddToBlacklist() ), actionCollection(), "addBlacklist" );
+  m_actionRefresh = new TDEAction( i18n( "&Refresh messages" ), "reload", Key_F5, this, TQ_SLOT( slotRefresh() ), actionCollection(), "refresh" );
+  new TDEAction( i18n( "Show &header of highlighted messages" ), "letter-closed", Key_F2, this, TQ_SLOT( slotShowHeader() ), actionCollection(), "show_header" );
+  new TDEAction( i18n( "Show &complete highlighted messages" ), "letter-open", Key_F3, this, TQ_SLOT( slotShowMessage() ), actionCollection(), "show_complete" );
+  new TDEAction( i18n( "&Delete highlighted messages" ), "eraser", Key_Delete, this, TQ_SLOT( slotDelete() ), actionCollection(), "delete" );
+  new TDEAction( i18n( "S&top current transfer" ), "process-stop", 0, this, TQ_SLOT( slotStop() ), actionCollection(), "stop" );
+  new TDEAction( i18n( "Show Filter Log" ), "text-x-log", Key_F4, this, TQ_SLOT( slotShowFilterLog() ), actionCollection(), "show_filterlog" );
+  new TDEAction( i18n( "Add sender to whitelist" ), "add_user", 0, this, TQ_SLOT( slotAddToWhitelist() ), actionCollection(), "addWhitelist" );
+  new TDEAction( i18n( "Add sender to blacklist" ), "delete_user", 0, this, TQ_SLOT( slotAddToBlacklist() ), actionCollection(), "addBlacklist" );
 
   // setup menu
-  KStdAction::preferences( this, SLOT( slotSetup() ), actionCollection() );
-  KStdAction::configureToolbars( this, SLOT( slotEditToolbars() ), actionCollection() );
+  KStdAction::preferences( this, TQ_SLOT( slotSetup() ), actionCollection() );
+  KStdAction::configureToolbars( this, TQ_SLOT( slotEditToolbars() ), actionCollection() );
 
   //create menu items for toggle tool and status bar
   setStandardToolBarMenuEnabled( true );
   createStandardStatusBarAction();
 
   //help menu
-  new TDEAction( i18n( "Send &Feedback Mail" ), "email", 0, this, SLOT( slotSendFeedbackMail() ),actionCollection(), "sendFeedback" );
+  new TDEAction( i18n( "Send &Feedback Mail" ), "email", 0, this, TQ_SLOT( slotSendFeedbackMail() ),actionCollection(), "sendFeedback" );
 
   //for account context menu
-  new TDEAction(i18n( "Setup &account" ), "tool", 0, this, SLOT( slotSetupAccount() ), actionCollection(), "setupAccount" );
+  new TDEAction(i18n( "Setup &account" ), "tool", 0, this, TQ_SLOT( slotSetupAccount() ), actionCollection(), "setupAccount" );
 }
 
 
@@ -619,8 +619,8 @@ void KShowMailApp::slotRefreshReady( )
       {
         //create a message dialog
         m_pAlertDialog = new AlertDialog( this );
-        connect( m_pAlertDialog, SIGNAL( destroyed() ), SLOT( slotAlertDestroyed() ) );
-        connect( m_pAlertDialog, SIGNAL( signalOk() ), SLOT( slotAlertOk() ) );
+        connect( m_pAlertDialog, TQ_SIGNAL( destroyed() ), TQ_SLOT( slotAlertDestroyed() ) );
+        connect( m_pAlertDialog, TQ_SIGNAL( signalOk() ), TQ_SLOT( slotAlertOk() ) );
       }
     }
 
@@ -760,7 +760,7 @@ void KShowMailApp::slotSetup( )
     SetupDialog->addModule( "kshowmailconfiglog.desktop" );
 
     //If the configuration was changed, it will call slotConfChanged
-    connect( SetupDialog, SIGNAL( configCommitted() ), this, SLOT( slotConfChanged() ) );
+    connect( SetupDialog, TQ_SIGNAL( configCommitted() ), this, TQ_SLOT( slotConfChanged() ) );
   }
 
   //execute preferences dialog
