@@ -57,8 +57,8 @@ KshowmailView::KshowmailView(TQWidget *parent, const char *name):
   m_pListAccounts->addColumn( i18n( "Messages" ), DEFAULT_WIDTH_ACCOUNT_MESSAGES );
   m_pListAccounts->addColumn( i18n( "Size" ), DEFAULT_WIDTH_ACCOUNT_SIZE );
   m_pListAccounts->setAllColumnsShowFocus( true );
-  connect( m_pListAccounts, SIGNAL( rightButtonClicked( TQListViewItem*, const TQPoint &, int ) ), SLOT( slotAccountContext( TQListViewItem*, const TQPoint &, int ) ) );
-  connect( m_pListAccounts, SIGNAL( clicked( TQListViewItem*, const TQPoint &, int) ), SLOT( slotAccountClicked( TQListViewItem*, const TQPoint &, int ) ) );
+  connect( m_pListAccounts, TQ_SIGNAL( rightButtonClicked( TQListViewItem*, const TQPoint &, int ) ), TQ_SLOT( slotAccountContext( TQListViewItem*, const TQPoint &, int ) ) );
+  connect( m_pListAccounts, TQ_SIGNAL( clicked( TQListViewItem*, const TQPoint &, int) ), TQ_SLOT( slotAccountClicked( TQListViewItem*, const TQPoint &, int ) ) );
 
   //create message list
   m_pListMessages = new TDEListView( this, "messages" );
@@ -75,9 +75,9 @@ KshowmailView::KshowmailView(TQWidget *parent, const char *name):
   m_pListMessages->addColumn( i18n( "Size" ), DEFAULT_WIDTH_MESSAGE_SIZE );
   m_pListMessages->addColumn( i18n( "Content" ), DEFAULT_WIDTH_MESSAGE_CONTENT );
   m_pListMessages->addColumn( i18n( "State" ),  DEFAULT_WIDTH_MESSAGE_STATE );
-  connect( m_pListMessages, SIGNAL( rightButtonClicked( TQListViewItem*, const TQPoint &, int) ), SLOT( slotMessageContext( TQListViewItem*, const TQPoint &, int ) ) );
-  connect( m_pListMessages, SIGNAL( doubleClicked( TQListViewItem* ) ), SLOT( slotMessageDoubleClicked( TQListViewItem* ) ) );
-  connect( m_pListMessages, SIGNAL( clicked( TQListViewItem* ) ), SLOT( slotMessageClicked( TQListViewItem* ) ) );
+  connect( m_pListMessages, TQ_SIGNAL( rightButtonClicked( TQListViewItem*, const TQPoint &, int) ), TQ_SLOT( slotMessageContext( TQListViewItem*, const TQPoint &, int ) ) );
+  connect( m_pListMessages, TQ_SIGNAL( doubleClicked( TQListViewItem* ) ), TQ_SLOT( slotMessageDoubleClicked( TQListViewItem* ) ) );
+  connect( m_pListMessages, TQ_SIGNAL( clicked( TQListViewItem* ) ), TQ_SLOT( slotMessageClicked( TQListViewItem* ) ) );
 
   //read the geometry from the application config file
   readOptions();
