@@ -71,7 +71,7 @@ void ShowRecord::readStoredMails( TQDomElement& parent )
 
 bool ShowRecord::hasSelectedMails( )
 {
-  bool selected = false;    //TRUE when a selected mail was found
+  bool selected = false;    //true when a selected mail was found
   ShowRecordElem* mail;     //mail which we want to check
 
   //get first mail
